#
# spec file for package exec-maven-plugin
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           exec-maven-plugin
Version:        3.0.0
Release:        150200.3.4.3
Summary:        Exec Maven Plugin
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://www.mojohaus.org/exec-maven-plugin/
Source0:        https://repo1.maven.org/maven2/org/codehaus/mojo/exec-maven-plugin/%{version}/exec-maven-plugin-%{version}-source-release.zip
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  unzip
BuildRequires:  mvn(org.apache.commons:commons-exec)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.shared:maven-artifact-transfer)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.mojo:mojo-parent:pom:)
BuildRequires:  mvn(org.codehaus.plexus:plexus-component-annotations)
BuildRequires:  mvn(org.codehaus.plexus:plexus-component-metadata)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildArch:      noarch

%description
A plugin to allow execution of system and Java programs.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n exec-maven-plugin-%{version}

sed -i 's/\r$//' LICENSE.txt
find . -name *.jar -delete

%pom_remove_plugin :animal-sniffer-maven-plugin

#Drop test part. sonatype-aerther not available
%pom_remove_dep :mockito-core
%pom_remove_dep :maven-plugin-testing-harness
%pom_remove_dep :plexus-interpolation

rm -rf src/test/

%build
%{mvn_build} -f

%install
%mvn_install

%files -f .mfiles
%license LICENSE.txt
%dir %{_javadir}/%{name}

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%changelog
* Tue Mar 22 2022 fstrba@suse.com
- Upgrade to upstream version 3.0.0
  * Bug Fixes
    + Resolving "target" dir via "${project.build.directory}", so
    to make sure it can be resolved correctly within multi-module
    builds and if another name than "target" has been configured
    [#124]
    + Ensure mojo descriptors are extracted after compilation #123
    + Argument file for modulepath is generated wrongly when paths
    contains spaces #115
    + java.lang.String cannot be cast to
    org.codehaus.mojo.exec.Modulepath #75
  * Enhancement
    + Resolves #152 - Adds option to redirect program output of
    exec:exec to the maven logger. #153
    + Program output can be difficult to trace and may be jumbled
    with Maven logs when running Maven with multiple threads #152
    + Fix type in Property.java #147
    + Correct spelling and remove redundant "small" #142
    + Fix typo #140
    + <timeout> configuration parameter #128
    + Methodhandles #119
    + Introduce Mock Repository Manager #117
    + Improved docs about <environmentVariables/> config of
    exec:exec goal #104
    + Add CodeTriage badge to mojohaus/exec-maven-plugin #96
    + [Enhancement] Support for JPMS module path for exec:java #90
- Removed patch:
  * exec-maven-plugin-1.6.0-Port-to-Maven-3.patch
    + not needed any more with this version
* Sat Apr  6 2019 jengelh@inai.de
- Avoid trivial name repetition in summary.
* Fri Apr  5 2019 fstrba@suse.com
- Initial packaging of exec-maven-plugin 1.6.0
